@@ -28,6 +28,7 @@
 #include <signal.h>
 #include <gdk/gdkkeysyms.h>
 #include <math.h>
+
 #include "procman.h"
 #include "callbacks.h"
 #include "interface.h"
@@ -36,9 +37,10 @@
 #include "procactions.h"
 #include "load-graph.h"
 #include "cellrenderer.h"
+#include "util.h"
 
-void	cb_toggle_tree (GtkMenuItem *menuitem, gpointer data);
-void	cb_toggle_threads (GtkMenuItem *menuitem, gpointer data);
+static void	cb_toggle_tree (GtkMenuItem *menuitem, gpointer data);
+static void	cb_toggle_threads (GtkMenuItem *menuitem, gpointer data);
 
 
 static GnomeUIInfo file1_menu_uiinfo[] =
@@ -51,30 +53,30 @@ static GnomeUIInfo edit1_menu_uiinfo[] =
 {
  	{
  	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the importance (nice value) of a process"),
-	 cb_renice, NULL, NULL, 0, 0,
+	 cb_renice, NULL, NULL, 0, NULL,
 	 'r', GDK_CONTROL_MASK
 	},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide a process"),
-	 cb_hide_process, NULL, NULL, 0, 0,
+	 cb_hide_process, NULL, NULL, 0, NULL,
 	 'h', GDK_CONTROL_MASK
 	}, 
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("End _Process"), N_("Force a process to finish."),
-	 cb_end_process, NULL, NULL, 0, 0,
+	 cb_end_process, NULL, NULL, 0, NULL,
 	 'e', GDK_CONTROL_MASK
 	},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish now."),
-	 cb_kill_process, NULL, NULL, 0, 0,
+	 cb_kill_process, NULL, NULL, 0, NULL,
 	 'k', GDK_CONTROL_MASK
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Hidden Processes"), 
 	 		    N_("View and edit your list of hidden processes"),
-	 cb_show_hidden_processes, NULL, NULL, 0, 0,
+	 cb_show_hidden_processes, NULL, NULL, 0, NULL,
 	 'p', GDK_CONTROL_MASK
 	},
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM (cb_preferences_activate, NULL),
@@ -85,18 +87,18 @@ static GnomeUIInfo view1_menu_uiinfo[] =
 {
 	{
 	 GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("View the memory maps associated with a process"),
-	 cb_show_memory_maps, NULL, NULL, 0, 0,
+	 cb_show_memory_maps, NULL, NULL, 0, NULL,
 	 'm', GDK_CONTROL_MASK
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("Process _Dependencies"), N_("Display a tree showing process dependencies"),
-	 cb_toggle_tree, NULL, NULL, 0, 0,
+	 cb_toggle_tree, NULL, NULL, 0, NULL,
 	 'd', GDK_CONTROL_MASK
 	}, 
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Threads"), N_("Display threads (subprocesses)"),
-	 cb_toggle_threads, NULL, NULL, 0, 0,
+	 cb_toggle_threads, NULL, NULL, 0, NULL,
 	 't', GDK_CONTROL_MASK
 	}, 
 	GNOMEUIINFO_END
@@ -122,42 +124,40 @@ static GnomeUIInfo popup_menu_uiinfo[] =
 {
 	{
  	  GNOME_APP_UI_ITEM, N_("_Change Priority..."), N_("Change the importance (nice value) of a process"),
-	 popup_menu_renice, NULL, NULL, 0, 0,
+	 popup_menu_renice, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	{
  	  GNOME_APP_UI_ITEM, N_("_Memory Maps"), N_("View the memory maps associated with a process"),
-	 popup_menu_show_memory_maps, NULL, NULL, 0, 0,
+	 popup_menu_show_memory_maps, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
  	  GNOME_APP_UI_ITEM, N_("_Hide Process"), N_("Hide a process"),
-	 popup_menu_hide_process, NULL, NULL, 0, 0,
+	 popup_menu_hide_process, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	GNOMEUIINFO_SEPARATOR,
 	{
  	  GNOME_APP_UI_ITEM, N_("_End Process"), N_("Force a process to finish"),
-	 popup_menu_end_process, NULL, NULL, 0, 0,
+	 popup_menu_end_process, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	{
  	  GNOME_APP_UI_ITEM, N_("_Kill Process"), N_("Force a process to finish now"),
-	 popup_menu_kill_process, NULL, NULL, 0, 0,
+	 popup_menu_kill_process, NULL, NULL, 0, NULL,
 	 0, 0
 	},
 	GNOMEUIINFO_END
 };
 
-gchar *moreinfolabel = N_("More _Info >>");
-gchar *lessinfolabel = N_("<< Less _Info");
 
-GtkWidget *infobutton;
-GtkWidget *infolabel;
-GtkWidget *endprocessbutton;
-GtkWidget *popup_menu;
-GtkWidget *sys_pane;
+static GtkWidget *infolabel = NULL;
+static GtkWidget *endprocessbutton = NULL;
+static GtkWidget *popup_menu = NULL;
+static GtkWidget *sys_pane = NULL;
+
 
 gint
 get_sys_pane_pos (void)
@@ -177,6 +177,7 @@ create_proc_view (ProcData *procdata)
 	GtkWidget *infobox;
 	GtkWidget *label;
 	GtkWidget *hbox2;
+	GtkWidget *infobutton;
 
 	vbox1 = gtk_vbox_new (FALSE, 18);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), 12);
@@ -307,23 +308,20 @@ make_title_label (const char *text)
 static void
 cpu_size_request (GtkWidget *box, GtkRequisition *req, ProcData *procdata)
 {
-	if (req->width > procdata->cpu_label_fixed_width)
-		procdata->cpu_label_fixed_width = req->width;
-		
-	req->width = procdata->cpu_label_fixed_width;
-	
+	req->width = procdata->cpu_label_fixed_width = \
+		MAX(req->width, procdata->cpu_label_fixed_width);
 }
 
 static GtkWidget *
 create_sys_view (ProcData *procdata)
 {
-	GtkWidget *vbox;
+	GtkWidget *vbox, *hbox;
 	GtkWidget *vpane;
 	GtkWidget *cpu_box, *mem_box, *disk_box;
 	GtkWidget *cpu_hbox, *mem_hbox, *disk_hbox;
 	GtkWidget *cpu_graph_box, *mem_graph_box;
 	GtkWidget *label,*cpu_label, *spacer;
-	GtkWidget *hbox, *table;
+	GtkWidget *table;
 	GtkWidget *color_picker;
 	GtkWidget *scrolled;
 	GtkWidget *disk_tree;
@@ -331,14 +329,19 @@ create_sys_view (ProcData *procdata)
 	GtkTreeViewColumn *col;
 	GtkCellRenderer *cell;
 	GtkSizeGroup *sizegroup;
-	gchar *titles[5] = {_("Name"),
-			    _("Directory"),
-				_("Type"),
-			    _("Total"),
-			    _("Used"),
-				};
+
+	static const gchar *titles[5] = {
+	  N_("Name"),
+	  N_("Directory"),
+	  N_("Type"),
+	  N_("Total"),
+	  N_("Used"),
+	};
+
 	LoadGraph *cpu_graph, *mem_graph;
 	gint i;
+
+	PROCMAN_GETTEXT_ARRAY_INIT(titles);
 	
 	vpane = gtk_vpaned_new ();
 	sys_pane = vpane;
@@ -369,18 +372,17 @@ create_sys_view (ProcData *procdata)
 	cpu_graph_box = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (cpu_hbox), cpu_graph_box, TRUE, TRUE, 0);
 
-	cpu_graph = load_graph_new (CPU_GRAPH, procdata);
+	cpu_graph = load_graph_new (LOAD_GRAPH_CPU, procdata);
 	gtk_box_pack_start (GTK_BOX (cpu_graph_box), cpu_graph->main_widget, TRUE, TRUE, 0);
 
 	sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
+
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX (cpu_graph_box), hbox, FALSE, FALSE, 0);
+
 	for (i=0;i<procdata->config.num_cpus; i++) {
 		GtkWidget *temp_hbox;
 		gchar *text;
-		/* Two per row */
-		if (fabs(fmod(i,2) - 0) < .01) {
-			hbox = gtk_hbox_new (FALSE, 12);
-			gtk_box_pack_start (GTK_BOX (cpu_graph_box), hbox, FALSE, FALSE, 0);
-		}
 		
 		temp_hbox = gtk_hbox_new (FALSE, 6);
 		gtk_box_pack_start (GTK_BOX (hbox), temp_hbox, FALSE, FALSE, 0);
@@ -430,11 +432,11 @@ create_sys_view (ProcData *procdata)
 	gtk_box_pack_start (GTK_BOX (mem_hbox), mem_graph_box, TRUE, TRUE, 0);
 
 
-	mem_graph = load_graph_new (MEM_GRAPH, procdata);
+	mem_graph = load_graph_new (LOAD_GRAPH_MEM, procdata);
 	gtk_box_pack_start (GTK_BOX (mem_graph_box), mem_graph->main_widget, 
 			    TRUE, TRUE, 0);
 	
-	table = gtk_table_new (2, 6, FALSE);
+	table = gtk_table_new (2, 7, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE (table), 6);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
 	gtk_box_pack_start (GTK_BOX (mem_graph_box), table, 
@@ -467,6 +469,11 @@ create_sys_view (ProcData *procdata)
 	gtk_table_attach (GTK_TABLE (table), mem_graph->memtotal_label, 4, 5, 0, 1, 
 			  GTK_FILL, 0, 0, 0);
 	
+	mem_graph->mempercent_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->mempercent_label), 1.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->mempercent_label, 5, 6, 0, 1, 
+			  GTK_FILL, 0, 0, 0);
+			  
 	color_picker = gnome_color_picker_new ();
 	gnome_color_picker_set_i16 (GNOME_COLOR_PICKER (color_picker), 
 				    mem_graph->colors[3].red,
@@ -494,6 +501,11 @@ create_sys_view (ProcData *procdata)
 	gtk_table_attach (GTK_TABLE (table), mem_graph->swaptotal_label, 4, 5, 1, 2, 
 			  GTK_FILL, 0, 0, 0);	
 	
+	mem_graph->swappercent_label = gtk_label_new ("");
+	gtk_misc_set_alignment (GTK_MISC (mem_graph->swappercent_label), 1.0, 0.5);
+	gtk_table_attach (GTK_TABLE (table), mem_graph->swappercent_label, 5, 6, 1, 2, 
+			  GTK_FILL, 0, 0, 0);
+			  
 	procdata->mem_graph = mem_graph;
 	gtk_widget_show_all (vbox);
 
@@ -570,7 +582,7 @@ create_sys_view (ProcData *procdata)
 	gtk_tree_view_column_set_attributes (col, cell,
 					     "text", 5,
 					     NULL);
-	gtk_tree_view_column_set_title (col, _(titles[4]));
+	gtk_tree_view_column_set_title (col, titles[4]);
 		
 	
 	cell = procman_cell_renderer_progress_new ();
@@ -633,7 +645,7 @@ create_main_window (ProcData *procdata)
 	gtk_widget_show (tab_label2);
 	gtk_notebook_append_page (GTK_NOTEBOOK (notebook), sys_box, tab_label2);
 	
-	appbar1 = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_NEVER);
+	appbar1 = gtk_statusbar_new();
 	gnome_app_set_statusbar (GNOME_APP (app), appbar1);
 	
 	g_signal_connect (G_OBJECT (app), "delete_event",
@@ -749,27 +761,23 @@ create_simple_view_dialog (ProcData *procdata)
 }
 
 void
-toggle_infoview (ProcData *data)
+toggle_infoview (ProcData *procdata)
 {
-	ProcData *procdata = data;
-	GtkWidget *label;
-	
-	label = infolabel;
-		
-	if (procdata->config.show_more_info == FALSE)
+	if (procdata->config.show_more_info)
+	{
+		gtk_widget_hide (procdata->infobox);
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (infolabel),
+						  _("More _Info >>"));
+	}
+	else
 	{
 		infoview_update (procdata);
 		gtk_widget_show_all (procdata->infobox);
-		procdata->config.show_more_info = TRUE;	
-		gtk_label_set_text_with_mnemonic (GTK_LABEL (label),_(lessinfolabel)); 
- 				
-	}			
-	else
-	{
-		gtk_widget_hide (procdata->infobox);
-		procdata->config.show_more_info = FALSE;
- 		gtk_label_set_text_with_mnemonic (GTK_LABEL (label),_(moreinfolabel)); 
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (infolabel),
+						  _("<< Less _Info"));
 	}
+
+	procdata->config.show_more_info = ! procdata->config.show_more_info;
 }
 
 void
@@ -807,7 +815,7 @@ update_sensitivity (ProcData *data, gboolean sensitivity)
 	}
 }
 
-void		
+static void		
 cb_toggle_tree (GtkMenuItem *menuitem, gpointer data)
 {
 	ProcData *procdata = data;
@@ -823,7 +831,7 @@ cb_toggle_tree (GtkMenuItem *menuitem, gpointer data)
 	
 }
 
-void		
+static void		
 cb_toggle_threads (GtkMenuItem *menuitem, gpointer data)
 {
 	ProcData *procdata = data;
