@@ -32,10 +32,11 @@
 #include "util.h"
 #include "load-graph.h"
 
-GtkWidget *renice_dialog = NULL;
-GtkWidget *prefs_dialog = NULL;
-gint new_nice_value = 0;
-int kill_signal = SIGTERM;
+static GtkWidget *renice_dialog = NULL;
+static GtkWidget *prefs_dialog = NULL;
+static gint new_nice_value = 0;
+
+/* public */ int kill_signal = SIGTERM;
 
 static void
 cb_show_hide_message_toggled (GtkToggleButton *button, gpointer data)
@@ -77,8 +78,10 @@ procdialog_create_hide_dialog (ProcData *data)
 	GtkWidget *label;
 	GtkWidget *align;
 	GtkWidget *icon;
-	gchar *header  = _("Are you sure you want to hide this process?");
-	gchar *message = _("If you hide a process, you can unhide it by selecting 'Hidden Processes' in the Edit menu.");
+	const gchar *header  = _("Are you sure you want to hide this process?");
+	const gchar *message = _("If you hide a process, you can unhide it by "
+				 "selecting 'Hidden Processes' in the Edit "
+				 "menu.");
 	gchar *title;
 		  			
   	messagebox1 = gtk_dialog_new ();
@@ -106,7 +109,7 @@ procdialog_create_hide_dialog (ProcData *data)
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 	gtk_widget_show (vbox);
 	
-	title = g_strconcat ("<b>", _(header), "</b>", NULL);
+	title = g_strdup_printf("<b>%s</b>", header);
 	label = gtk_label_new (title);  
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -314,7 +317,6 @@ procdialog_create_kill_dialog (ProcData *data, int signal)
 static gchar *
 get_nice_level (gint nice)
 {
-
 	if (nice < -7)
 		return _("(Very High Priority)");
 	else if (nice < -2)
@@ -325,7 +327,6 @@ get_nice_level (gint nice)
 		return _("(Low Priority)");
 	else
 		return _("(Very Low Priority)");
-	
 }
 
 static void
@@ -571,31 +572,6 @@ update_disks_update_interval (GtkWidget *widget, GdkEventFocus *event, gpointer
 	return FALSE;
 }
 
-static void		
-bg_color_changed (GnomeColorPicker *cp, guint r, guint g, guint b,
-		  guint a, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gchar *color;
-	
-	color = g_strdup_printf("#%04x%04x%04x", r, g, b);
-	gconf_client_set_string (client, "/apps/procman/bg_color", color, NULL);
-	g_free (color);
-}
-
-static void		
-frame_color_changed (GnomeColorPicker *cp, guint r, guint g, guint b,
-		  guint a, gpointer data)
-{
-	ProcData *procdata = data;
-	GConfClient *client = procdata->client;
-	gchar *color;
-	
-	color = g_strdup_printf("#%04x%04x%04x", r, g, b);
-	gconf_client_set_string (client, "/apps/procman/frame_color", color, NULL);
-	g_free (color);
-}
 
 static void
 proc_field_toggled (GtkToggleButton *button, gpointer data)
@@ -898,7 +874,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 				    procdata->config.bg_color.green,
 				    procdata->config.bg_color.blue, 0);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			          G_CALLBACK (bg_color_changed), procdata);
+			          G_CALLBACK (cb_bg_color_changed), procdata);
 	gtk_box_pack_start (GTK_BOX (hbox2), color_picker,TRUE, TRUE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
@@ -917,7 +893,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 				    procdata->config.frame_color.green,
 				    procdata->config.frame_color.blue, 0);
 	g_signal_connect (G_OBJECT (color_picker), "color_set",
-			    G_CALLBACK (frame_color_changed), procdata);	  
+			    G_CALLBACK (cb_frame_color_changed), procdata);	  
 	gtk_box_pack_start (GTK_BOX (hbox2), color_picker, TRUE, TRUE, 0);	
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
 	gtk_widget_show (color_picker);
