@@ -16,8 +16,8 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
  */
-#ifndef _PROCMAN_H_
-#define _PROCMAN_H_
+#ifndef _PROCMAN_PROCMAN_H_
+#define _PROCMAN_PROCMAN_H_
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gnome.h>
@@ -90,17 +90,19 @@ struct _LoadGraph {
     GtkWidget *cpu_labels[GLIBTOP_NCPU];
     GtkWidget *memused_label;
     GtkWidget *memtotal_label;
+    GtkWidget *mempercent_label;
     GtkWidget *swapused_label;
     GtkWidget *swaptotal_label;
+    GtkWidget *swappercent_label;
     GdkPixmap *pixmap;
     GdkGC *gc;
     int timer_index;
     
     gboolean draw;
 
-    long cpu_time [GLIBTOP_NCPU] [NCPUSTATES];
-    long cpu_last [GLIBTOP_NCPU] [NCPUSTATES];
-    int cpu_initialized;       
+    guint64 cpu_time [GLIBTOP_NCPU] [NCPUSTATES];
+    guint64 cpu_last [GLIBTOP_NCPU] [NCPUSTATES];
+    gboolean cpu_initialized;       
 };
 
 enum
@@ -122,17 +124,17 @@ struct _ProcInfo
 	gchar		*name;
 	gchar		*user;
 	gchar		*arguments;
-	gint		mem;
-	gint		cpu;
+	guint64		mem;
+	guint8		pcpu;
 	gint		pid;
 	gint		parent_pid;
-	gint		cpu_time_last;
+	guint64		cpu_time_last;
 	gint		nice;
-	gint		vmsize;
-	gint		memres;
-	gint		memshared;
-	gint		memrss;
-        gint            memxserver;
+	guint64		vmsize;
+	guint64		memres;
+	guint64		memshared;
+	guint64		memrss;
+        guint64            memxserver;
 	gchar		*status;
 	gboolean	running;
 	gboolean	is_thread;
@@ -163,4 +165,4 @@ void		procman_save_config (ProcData *data);
 void		procman_save_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix);
 gboolean	procman_get_tree_state (GConfClient *client, GtkWidget *tree, gchar *prefix);
 
-#endif
+#endif /* _PROCMAN_PROCMAN_H_ */
